@@ -1,16 +1,17 @@
-use 5.14.0;
+use 5.10.1;
 use strict;
 use warnings;
 
 package Stenciller::Plugin::ToHtmlPreBlock;
 
-our $VERSION = '0.1302'; # VERSION:
+our $VERSION = '0.1400'; # VERSION:
 # ABSTRACT: A plugin that transforms to html
 
 use Moose;
-use List::AllUtils qw/first_index/;
 with 'Stenciller::Transformer';
+use namespace::autoclean;
 
+use List::MoreUtils qw/first_index/;
 use Types::Standard qw/Bool Str Maybe/;
 use MooseX::AttributeShortcuts;
 use HTML::Entities 'encode_entities';
@@ -72,6 +73,8 @@ sub pre {
     return join '' => ('<pre>', join ("\n" => @encoded_lines), '</pre>');
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -86,7 +89,7 @@ Stenciller::Plugin::ToHtmlPreBlock - A plugin that transforms to html
 
 =head1 VERSION
 
-Version 0.1302, released 2015-11-28.
+Version 0.1400, released 2016-02-03.
 
 
 
@@ -136,7 +139,7 @@ Erik Carlsson <info@code301.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Erik Carlsson.
+This software is copyright (c) 2016 by Erik Carlsson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
