@@ -1,15 +1,17 @@
-use 5.14.0;
+use 5.10.1;
 use strict;
 use warnings;
 
 package Stenciller::Plugin::ToUnparsedText;
 
-our $VERSION = '0.1302'; # VERSION:
+our $VERSION = '0.1400'; # VERSION:
 # ABSTRACT: A plugin that doesn't transform the text
 
 use Moose;
-use List::AllUtils qw/first_index/;
 with 'Stenciller::Transformer';
+use namespace::autoclean;
+
+use List::MoreUtils qw/first_index/;
 use Types::Standard qw/Bool/;
 
 has text_as_html_pod => (
@@ -18,7 +20,6 @@ has text_as_html_pod => (
     default => 0,
 );
 
-
 sub transform {
     my $self = shift;
     my $transform_args = shift;
@@ -57,6 +58,8 @@ sub maybe_as_html_pod {
 
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -71,7 +74,7 @@ Stenciller::Plugin::ToUnparsedText - A plugin that doesn't transform the text
 
 =head1 VERSION
 
-Version 0.1302, released 2015-11-28.
+Version 0.1400, released 2016-02-03.
 
 
 
@@ -130,7 +133,7 @@ Erik Carlsson <info@code301.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Erik Carlsson.
+This software is copyright (c) 2016 by Erik Carlsson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
