@@ -1,23 +1,17 @@
-use 5.14.0;
+use 5.10.1;
 use strict;
 use warnings;
 
-use Moops;
+package Types::Stenciller;
 
-# PODNAME: Types::Stenciller
+our $VERSION = '0.1400'; # VERSION
 # ABSTRACT: Types for Stenciller
 
-library Types::Stenciller
-extends Types::Standard, Types::Path::Tiny
+use Type::Library -base, -declare => qw/Stencil Stenciller/;
+use Type::Utils -all;
 
-{
-
-    our $VERSION = '0.1302'; # VERSION:
-
-    class_type Stenciller => { class => 'Stenciller::Wrap' };
-    class_type Stencil    => { class => 'Stenciller::Stencil' };
-
-}
+class_type Stenciller => { class => 'Stenciller' };
+class_type Stencil    => { class => 'Stenciller::Stencil' };
 
 1;
 
@@ -33,7 +27,7 @@ Types::Stenciller - Types for Stenciller
 
 =head1 VERSION
 
-Version 0.1302, released 2015-11-28.
+Version 0.1400, released 2016-02-03.
 
 
 
@@ -75,7 +69,7 @@ Erik Carlsson <info@code301.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Erik Carlsson.
+This software is copyright (c) 2016 by Erik Carlsson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
